==> jc-1.4.0.tar.gz: java/nio/DirectByteBufferImpl__24ReadOnly.h <==
// final class java.nio.DirectByteBufferImpl$ReadOnly

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9a9842bb79e9de6a java_nio_Buffer
// @dep_class c56860d6af73feea java_nio_ByteBuffer
// @dep_class acc48c6bb960328b java_nio_DirectByteBufferImpl
// @dep_class f4960895ae0f451b java_nio_DirectByteBufferImpl__24ReadOnly

// header file dependencies
// @dep_header java_nio_DirectByteBufferImpl

#include "java/nio/DirectByteBufferImpl.h"

#ifndef _JC_java_nio_DirectByteBufferImpl__24ReadOnly_H_
#define _JC_java_nio_DirectByteBufferImpl__24ReadOnly_H_

// Forward structure declarations
struct _jc_gnu_classpath_RawData$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_nio_ByteBuffer$object;

// Typedefs
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$object;

typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype;

// Constructors
extern void _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$_init$1316da41ff5f3d11(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, struct _jc_java_lang_Object$object *, struct _jc_gnu_classpath_RawData$object *, jint, jint, jint);

// Virtual methods
extern jboolean _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$isReadOnly$c9d2a7ec56d3b05a(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *);
extern struct _jc_java_nio_ByteBuffer$object *_jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$put$2d112242bedcc6d4(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jbyte);
extern struct _jc_java_nio_ByteBuffer$object *_jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$put$34b0fb602e480ab8(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jint, jbyte);

// Virtual method descriptors
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method_info$isReadOnly$c9d2a7ec56d3b05a;
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method_info$put$2d112242bedcc6d4;
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method_info$put$34b0fb602e480ab8;

// Virtual methods structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods {
	jboolean	(*isReadOnly$c9d2a7ec56d3b05a)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *);
	struct _jc_java_nio_ByteBuffer$object	*(*put$2d112242bedcc6d4)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jbyte);
	struct _jc_java_nio_ByteBuffer$object	*(*put$34b0fb602e480ab8)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jint, jbyte);
};

// Vtable
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_Buffer$vmethods	java_nio_Buffer;
	_jc_java_nio_ByteBuffer$vmethods	java_nio_ByteBuffer;
	_jc_java_nio_DirectByteBufferImpl$vmethods	java_nio_DirectByteBufferImpl;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods	java_nio_DirectByteBufferImpl__24ReadOnly;
};

// Vtype
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype {
	_jc_type			type;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs {
    _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs	java_nio_DirectByteBufferImpl__24ReadOnly;
    _jc_java_nio_DirectByteBufferImpl$sub_refs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_ByteBuffer$sub_refs	java_nio_ByteBuffer;
    _jc_java_nio_Buffer$sub_refs	java_nio_Buffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_Buffer$sub_nonrefs	java_nio_Buffer;
    _jc_java_nio_ByteBuffer$sub_nonrefs	java_nio_ByteBuffer;
    _jc_java_nio_DirectByteBufferImpl$sub_nonrefs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs	java_nio_DirectByteBufferImpl__24ReadOnly;
};

// Object instance structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object {
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype	*vtype;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype _jc_java_nio_DirectByteBufferImpl__24ReadOnly$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_DirectByteBufferImpl__24ReadOnly, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_DirectByteBufferImpl__24ReadOnly$class_object;

#endif	/* _JC_java_nio_DirectByteBufferImpl__24ReadOnly_H_ */

==> jc-1.4.6.tar.gz: java/nio/DirectByteBufferImpl__24ReadOnly.h <==
// final class java.nio.DirectByteBufferImpl$ReadOnly

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9a9842bb79e9de6a java_nio_Buffer
// @dep_class c56860d6af73feea java_nio_ByteBuffer
// @dep_class acc48c6bb960328b java_nio_DirectByteBufferImpl
// @dep_class f4960895ae0f451b java_nio_DirectByteBufferImpl__24ReadOnly

// header file dependencies
// @dep_header java_nio_DirectByteBufferImpl

#include "java/nio/DirectByteBufferImpl.h"

#ifndef _JC_java_nio_DirectByteBufferImpl__24ReadOnly_H_
#define _JC_java_nio_DirectByteBufferImpl__24ReadOnly_H_

// Forward structure declarations
struct _jc_gnu_classpath_RawData$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_nio_ByteBuffer$object;

// Typedefs
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$object;

typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype;

// Constructors
extern void _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$_init$1316da41ff5f3d11(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, struct _jc_java_lang_Object$object *, struct _jc_gnu_classpath_RawData$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$isReadOnly$c9d2a7ec56d3b05a(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_ByteBuffer$object *_jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$put$2d112242bedcc6d4(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jbyte) _JC_JCNI_ATTR;
extern struct _jc_java_nio_ByteBuffer$object *_jc_java_nio_DirectByteBufferImpl__24ReadOnly$method$put$34b0fb602e480ab8(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jint, jbyte) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method_info$isReadOnly$c9d2a7ec56d3b05a;
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method_info$put$2d112242bedcc6d4;
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadOnly$method_info$put$34b0fb602e480ab8;

// Virtual methods structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods {
	jboolean	(*isReadOnly$c9d2a7ec56d3b05a)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_ByteBuffer$object	*(*put$2d112242bedcc6d4)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jbyte) _JC_JCNI_ATTR;
	struct _jc_java_nio_ByteBuffer$object	*(*put$34b0fb602e480ab8)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object *, jint, jbyte) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_Buffer$vmethods	java_nio_Buffer;
	_jc_java_nio_ByteBuffer$vmethods	java_nio_ByteBuffer;
	_jc_java_nio_DirectByteBufferImpl$vmethods	java_nio_DirectByteBufferImpl;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vmethods	java_nio_DirectByteBufferImpl__24ReadOnly;
};

// Vtype
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype {
	_jc_type			type;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs {
    _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_refs	java_nio_DirectByteBufferImpl__24ReadOnly;
    _jc_java_nio_DirectByteBufferImpl$sub_refs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_ByteBuffer$sub_refs	java_nio_ByteBuffer;
    _jc_java_nio_Buffer$sub_refs	java_nio_Buffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_Buffer$sub_nonrefs	java_nio_Buffer;
    _jc_java_nio_ByteBuffer$sub_nonrefs	java_nio_ByteBuffer;
    _jc_java_nio_DirectByteBufferImpl$sub_nonrefs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_DirectByteBufferImpl__24ReadOnly$sub_nonrefs	java_nio_DirectByteBufferImpl__24ReadOnly;
};

// Object instance structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadOnly$object {
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype	*vtype;
	_jc_java_nio_DirectByteBufferImpl__24ReadOnly$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_DirectByteBufferImpl__24ReadOnly$vtype _jc_java_nio_DirectByteBufferImpl__24ReadOnly$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_DirectByteBufferImpl__24ReadOnly, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_DirectByteBufferImpl__24ReadOnly$class_object;

#endif	/* _JC_java_nio_DirectByteBufferImpl__24ReadOnly_H_ */
